@@ -3,9 +3,9 @@ from pydantic.errors import PydanticValueError
 
 
 class RangeBorderCrossing(PydanticValueError):
-    code = 'range.border_crossing'
-    msg_template = 'Make sure the borders do not cross'
+    code = "range.border_crossing"
+    msg_template = "Make sure the borders do not cross"
 
 
 class DatetimeBorderCrossing(RangeBorderCrossing):
-    code = 'datetime_range.border_crossing'
+    code = "datetime_range.border_crossing"
