@@ -1,30 +1,36 @@
 """Types for pydantic models"""
-from datetime import datetime
-from typing import Dict, List, Union
+from __future__ import annotations
 
 from bson import ObjectId
 from bson.errors import InvalidId
+from datetime import datetime
 from pydantic import BaseModel
+from typing import TYPE_CHECKING, Any, Callable, Generator, List, Union
 
 from .errors import DatetimeBorderCrossing
 
+if TYPE_CHECKING:
+    from pydantic.typing import DictStrAny
+
+    ValidatorClsMethod = Callable[[Any], Any]
+
 
 class ObjectIdStr(str):
     """Field for validate string like ObjectId"""
 
     @classmethod
-    def __get_validators__(cls):
+    def __get_validators__(cls) -> Generator["ValidatorClsMethod", None, None]:
         yield cls.validate
 
     @classmethod
-    def validate(cls, v):
+    def validate(cls, v: Union[ObjectId, str]) -> str:
         if isinstance(v, ObjectId):
             return str(v)
         else:
             try:
                 ObjectId(str(v))
             except InvalidId:
-                raise ValueError('Not a valid ObjectId')
+                raise ValueError("Not a valid ObjectId")
             return v
 
 
@@ -36,23 +42,23 @@ class DateTimeRange(BaseModel):
     Second elem - upper bound.
     """
 
-    gte: datetime = None
-    lte: datetime = None
+    gte: datetime
+    lte: datetime
 
     @classmethod
-    def __get_validators__(cls):
+    def __get_validators__(cls) -> Generator["ValidatorClsMethod", None, None]:
         yield cls.validate
 
     @classmethod
-    def validate(cls, v: Union[List, Dict], values=None):
+    def validate(cls, v: Union[List[Any], "DictStrAny"]) -> DateTimeRange:
         """Check border crossing"""
         gte, lte = None, None
         try:
             if isinstance(v, list):
                 gte, lte = v
             elif isinstance(v, dict):
-                gte = v.get('gte')
-                lte = v.get('lte')
+                gte = v.get("gte")
+                lte = v.get("lte")
         except IndexError:
             return cls(gte=gte, lte=lte)
 
